pro optimumscale,filenames,numberoffiles,scale,center,finallimits

; IDL routine
;
; optimumscale.pro v 0.5
;
;    This code makes a stab at estimating lat/long boundaries for
;    one or several MODIS level 1-b granules and then estimates
;    a scale value for possible use with the IDL orthographic map
;    projection.
; 
; v 0.5 notes:  scale is a guess. not very well tested. the result might be
;               non-optimum, despite the routine name. :)
;
; Keywords:
;   none
;
; Input:
;    filenames   string array  all filenames to be checked
;    numberoffiles integer     the number of files in filenames
;
; Output:
;    scale         real         estimated scale for orthographic projection
;    center        real array   lat long center of all files
;    finallimits   real array   lat long upper and lower bounds for all files
;
; Required routines:
;    none
;
; Developer
;  v .5         Mark Gray mag@climate.gsfc.nasa.gov
;               SM&A - SSG
;               MODIS - Atmosphere Group
;

minlat=0
minlong=0
limits=fltarr(numberoffiles,4)


for fileloop=0,numberoffiles-1 do  begin

   fileId = HDF_SD_START(filenames[fileloop], /READ)
   read_scaled_sds,latitude,range,fileid,'Latitude',/scaleNo,/offsetNo
   read_scaled_sds,longitude,range,fileid,'Longitude',/scaleNo,/offsetNo
   HDF_SD_END, fileId

   badvalues=where(latitude lt -300,badcount)
   for i=0 , 1 do begin

     if i eq 0 then array=latitude
     if i eq 1 then array=longitude

     badvalues=where(array lt -300, badcount)

     if badcount gt 0 then  begin
       arraysizetemp=size(array) 
       array[badvalues]= 0.
       mean=total(array)/(arraysizetemp[1]*arraysizetemp[2])
       array[badvalues]=mean 
     endif

     if i eq 0 then latitude=array
     if i eq 1 then longitude=array

   endfor
   limits[fileloop,0]=min(latitude)
   limits[fileloop,2]=max(latitude)
   limits[fileloop,1]=min(longitude)
   limits[fileloop,3]=max(longitude) 
endfor

finallimits=fltarr(4)
finallimits[0]=min(limits[*,0])
finallimits[2]=max(limits[*,2])
finallimits[1]=min(limits[*,1])
finallimits[3]=max(limits[*,3])

; OK, it's estimated guess time
; I assume that 1 degree is approx 150km to be generous

xsize=abs(finallimits[0]-finallimits[2])*150.e3
ysize=abs(finallimits[1]-finallimits[3])*150.e3
scale=(xsize/20.e-2+ysize/20.e-2)/2.

;assume we want, say, a 2000x2000 pixel
center=fltarr(2)
center[0]=(finallimits[0]+finallimits[2])/2.
center[1]=(finallimits[1]+finallimits[3])/2.
end
