pro setup_display,filenames,titlestring,outputname,scalesettings,latlonglimits,center,world=world,jpeg=jpeg,ps=ps,cylindrical=cylindrical

;*************************************************************************
; Modification history:
;  11/08/2001
;    Initial Release.
;
; Credits:
;  Written by Eric G. Moody and Mark Gray.
;  eric.moody@gsfc.nasa.gov
;  gray@climate.gsfc.nasa.gov
;  Climate and Radiation Branch
;  NASA Goddard Space Flight Center
;  Greenbelt, Maryland, U.S.A.
;
; License:
; This software is provided "as-is", without any express or
; implied warranty. In no event will the authors be held liable
; for any damages arising from the use of this software.
;
; Permission is granted to anyone to use this software and to alter
; it freely, subject to the following restrictions:
;
; 1. The origin of this software must not be misrepresented; you must
;    not claim you wrote the original software.
;
; 2. Altered source versions must be plainly marked as such, and must
;    not be misrepresented as being the original software.
;
; 3. This notice may not be removed or altered from any source distribution.
;*************************************************************************


numberoffiles=size(filenames)
numberoffiles=numberoffiles[1]
if keyword_set(ps) then begin
  if  keyword_set(world) then begin
     set_plot,'ps',/interp
     device,bits_per_pixel=8,$
          /color,$
          /helv,$
          font_size=14,$
          /landscape,$
          /encapsulated,$
          filename=outputname&!p.font=3
     marginX = intarr(2)
     marginX(0) = 3
     marginX(1) = 22
     map_set,/hammer,/isotropic,/noborder,noerase=noerase,xmargin=marginX
  endif else begin
     set_plot,'ps',/interp
     device,bits_per_pixel=8,$
          /color,$
          /helv,$
          font_size=14,$
          /landscape,$
          filename=outputname&!p.font=3
     marginX = intarr(2)
     marginX(0) = 3
     marginX(1) = 22
     map_set,/orthographic,center[0],center[1], $
       limit = latlonglimits, $
       title = '', $
       xmargin=marginx, ymargin=4,$
       /noborder, noerase = noerase

;if ps device
     clipping=!p.clip
     topspace=!d.y_size-clipping[3]
     textlinepoint_y=clipping[3]+topspace/2
     textlinepoint_x=fix(!d.x_size/2)
     xyouts,textlinepoint_x,textlinepoint_y,titlestring,/device,alignment=.5,/noclip,charsize=1.1
  endelse
endif


;  for the rgb output we need to setup the map_set in the z buffer to establish the cooredinate conversion and 
;  for combination later in the jpeg output
if keyword_set(jpeg) then begin
  xsize=1800
  ysize=1700
  if keyword_set(world) then begin
   ; no world jpegs yet
  endif else begin
     set_plot,'z'
     !p.font=3
     device,set_resolution=[xsize,ysize],set_character_size=[12,18];,set_font='Helvetica',/tt_font

;    set z-buffer image to white
     tempimage=bytarr(xsize,ysize)
     tempimage[0:xsize-1,0:ysize-1]=255
     tv,tempimage
     
     if keyword_set(cylindrical) then begin
;       map_set,/cylindrical,center[0],center[1],$
       map_set,/cylindrical,0.,0.,$
          limit = latlonglimits,$
          title = '', $
          /noborder,$
          xmargin=2,$
          ymargin=4,$
          noerase = noerase
     endif else begin
      map_set,/orthographic,center[0],center[1],$
;          scale = scalesetting,$
          limit = latlonglimits,$
          title = '', $
          /noborder,$
          xmargin=2,$
          ymargin=4,$
          noerase = noerase
    endelse
  endelse
  clipping=!p.clip
  topspace=!d.y_size-clipping[3]
;  textlinepoint_y=topspace-(fix(!d.y_ch_size/2))+clipping[3]
  textlinepoint_y=clipping[3]+topspace/2
  textlinepoint_x=fix(!d.x_size/2)
  xyouts,textlinepoint_x,textlinepoint_y,titlestring,/device,alignment=.5,/noclip,charsize=1.1,color=255

endif


LUTR=BYTARR(256)
LUTG=BYTARR(256)
LUTB=BYTARR(256)


;;;;;;;;;;;;;;;;;;
; RED
;;;;;;;;;;;;;;;;;;

FOR INDEX = 0,50 DO BEGIN
 DYDX = 173.0 - ((173.0*INDEX)/50.0)
 LUTR(INDEX) = BYTE(DYDX)
END

LUTR(51:113)=0

FOR I=114,145 DO BEGIN
 DX=FLOAT(I)-113.
 DYDX=(255.-0.)/(146.-113.)
 LUTR(I)=BYTE((DYDX*DX)+0.)
END

LUTR(146:230)=255

FOR I=231,255 DO BEGIN
 DYDX=255.0 - 75.0*(I-231.0)/(22.0)
 LUTR(I)=BYTE((DYDX))
END


;;;;;;;;;;;;;;;;;;
; GREEN
;;;;;;;;;;;;;;;;;;

LUTG(0:36)=0

FOR I=37,129 DO BEGIN
 DX=FLOAT(I)-36.
 DYDX=(255.-0.)/(130.-36.)
 LUTG(I)=BYTE((DYDX*DX)+0.)
END

LUTG(130:154)=255

FOR I=155,250 DO BEGIN
 DX=FLOAT(I)-154.
 DYDX=(0.-255.)/(251.-154.)
 LUTG(I)=BYTE((DYDX*DX)+255.)
END

LUTG(251:255)=0


;;;;;;;;;;;;;;;;;;
; BLUE
;;;;;;;;;;;;;;;;;;

FOR I=0,60 DO BEGIN
 DYDX = 255.0 - (85.0*(60-I)/60.0)
 LUTB(I)=BYTE(DYDX)
END

LUTB(61)=255

FOR I=62,64 DO BEGIN
 DX=FLOAT(I)-61.
 DYDX=(238.-255.)/(65.-61.)
 LUTB(I)=BYTE((DYDX*DX)+255.)

END

LUTB(65:77)=238

FOR I=78,124 DO BEGIN
 DX=FLOAT(I)-77.
 DYDX=(0.-238.)/(125.-77.)
 LUTB(I)=BYTE((DYDX*DX)+238.)
END

LUTB(125:255)=0


;;;;;;;;;;;;;;;;;;
; GREY-for greater than top limit.
;;;;;;;;;;;;;;;;;;
LUTR(253)=150
LUTG(253)=150
LUTB(253)=150

;;;;;;;;;;;;;;;;;;
; DARK GREY-for less than bottom limit.
;;;;;;;;;;;;;;;;;;
LUTR(0)=75
LUTG(0)=75
LUTB(0)=75

;;;;;;;;;;;;;;;;;;
; WHITE
;;;;;;;;;;;;;;;;;;
;reserve 254 (white) - background and coastlines
LUTR(254)=255
LUTG(254)=255
LUTB(254)=255


;;;;;;;;;;;;;;;;;;
; BLACK
;;;;;;;;;;;;;;;;;;
;reserve 255 (black) - text
LUTR(255)=0
LUTG(255)=0
LUTB(255)=0


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; LOAD NEW COLOR TABLE
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
TVLCT,LUTR,LUTG,LUTB


end
