pro addproduct,filename,latlongfile,colorimage,sds_name,xparameter, $
               productname,sds_limits,multidim_choice,diff_flag,    $
               delta_zero,fail,quick = quick

;*************************************************************************
; Modification history:
;  11/08/2001
;    Initial Release.
;
; Credits:
;  Written by Eric G. Moody and Mark Gray.
;  eric.moody@gsfc.nasa.gov
;  gray@climate.gsfc.nasa.gov
;  Climate and Radiation Branch
;  NASA Goddard Space Flight Center
;  Greenbelt, Maryland, U.S.A.
;
; License:
; This software is provided "as-is", without any express or
; implied warranty. In no event will the authors be held liable
; for any damages arising from the use of this software.
;
; Permission is granted to anyone to use this software and to alter
; it freely, subject to the following restrictions:
;
; 1. The origin of this software must not be misrepresented; you must
;    not claim you wrote the original software.
;
; 2. Altered source versions must be plainly marked as such, and must
;    not be misrepresented as being the original software.
;
; 3. This notice may not be removed or altered from any source distribution.
;*************************************************************************


;
fail=0


get_modis_data,filename,latlongfile,sds_name,latitude,longitude, $
               sds_data,fillvalue,fail1,datarange,multidim_choice
if fail1 ne 1 then begin

;Ensure they are floats:
fillvalue = float(fillvalue)
sds_data=float(sds_data)

;If we want a difference, add the Re, 2.1 micron result:
if (diff_flag eq 0) then begin
  ;We are plotting the effective radius, so read in the 2.1, and 
  ; add it to the difference.
  get_modis_data,filename,latlongfile,'Effective_Particle_Radius', $
                 latitude2,longitude2, EPR_data,fillvalue2,fail2,datarange,0

  EPR_data = float(EPR_data)
  fillvalue2 = float(fillvalue2)
 
  ;Reset the fill values to the fill value:
  index = where((sds_data eq fillvalue),fill_cnt)
  sds_data[*,*] = sds_data[*,*] + EPR_data[*,*]
  if fill_cnt gt 0 then sds_data[index] = fillvalue

endif else begin
  ;We are plotting the differences, and would like any value +- delta_zero 
  ; to be gray.

  ;Define the upper and lower limits to set to gray
  top_lim = delta_zero(1)
  bot_lim = delta_zero(0)
  ;Figure out the index of the upper and lower points to
  ; be shaded gray:
  tot_cb_levels = 254.
  delta_cb = (sds_limits(1)-sds_limits(0)) / tot_cb_levels
  tot_gray_lvls = fix( abs(top_lim-bot_lim) / delta_cb )

  bot_lvl = fix( abs(bot_lim-sds_limits(0))  /delta_cb )
  top_lvl = bot_lvl + tot_gray_lvls 

  ;Read in the color table, to adjust:
  tvlct,r,g,b,/get
 
  ;Set those levels to a light gray:
  r(bot_lvl:top_lvl) = 150B
  g(bot_lvl:top_lvl) = 150B
  b(bot_lvl:top_lvl) = 150B
  
  ;Set the top level to top -1 and bottom to bottom +1
  ; to avoid having repetitive grays:
  r(253) = r(252)
  g(253) = g(252)
  b(253) = b(252)
  r(0) = r(1)
  g(0) = g(1)
  b(0) = b(1)

  ;Set the color table:
  tvlct,r,g,b

endelse



array_size_temp=size(sds_data)

xsize=array_size_temp(1)
ysize=array_size_temp(2)

datarange=sds_limits
if keyword_set(quick) then colorproductmap,sds_data,$
                                         latitude,$
                                         longitude,$
                                         colorimage,$
                                         fillvalue,$
                                         datarange,$
                                         xparameter,$
                                         /dilateno
if not keyword_set(quick) then colorproductmap,sds_data,$
                                         latitude,$
                                         longitude,$
                                         colorimage,$
                                         fillvalue,$
                                         datarange,$
                                         xparameter,$
                                         /validrange

sds_data=0
latitude=0
longitude=0

endif else begin
  print,'no data here'
  fail=1
endelse
end
