pro colorproductmap, image, lat, lon,colorimage,fillvalue,range,$
                     xparameter,dilateNo=dilateNo,validrange=validrange

;*************************************************************************
; Modification history:
;  11/08/2001
;    Initial Release.
;
; Credits:
;  Written by Eric G. Moody and Mark Gray.
;  eric.moody@gsfc.nasa.gov
;  gray@climate.gsfc.nasa.gov
;  Climate and Radiation Branch
;  NASA Goddard Space Flight Center
;  Greenbelt, Maryland, U.S.A.
;
; License:
; This software is provided "as-is", without any express or
; implied warranty. In no event will the authors be held liable
; for any damages arising from the use of this software.
;
; Permission is granted to anyone to use this software and to alter
; it freely, subject to the following restrictions:
;
; 1. The origin of this software must not be misrepresented; you must
;    not claim you wrote the original software.
;
; 2. Altered source versions must be plainly marked as such, and must
;    not be misrepresented as being the original software.
;
; 3. This notice may not be removed or altered from any source distribution.
;*************************************************************************



if keyword_set( validrange ) then begin
  imin = float(range(0))
  imax = float(range(1))
endif else begin
  imin = min( image, max = imax )
endelse
;- set number of samples and lines for warped image

ns = !d.x_size
nl = !d.y_size
if ( !d.flags and 1 ) then begin
  ns = 1280L
  nl = long( float( ns ) * float( !d.y_size ) / float( !d.x_size ) )
endif

;- create resampled byte image
p = convert_coord( lon, lat, /data, /to_normal )
newimage = replicate( 0B, ns, nl )
newimage( p( 0, * ) * ( ns - 1 ), p( 1, * ) * ( nl - 1 ) ) = $
  bytscl( image, min = imin, max = imax, top = !d.table_size - 3 )


;-Set any fill value to black, or 255.
image2 = float(image)
fill_pixels = where((image2 eq fillvalue),fillcnt)
image2[*,*] = float(imax)
if fillcnt gt 0 then image2(fill_pixels) = float(imin)

bottom_vals = replicate( 0B, ns, nl )
bottom_vals( p( 0, * ) * ( ns - 1 ), p( 1, * ) * ( nl - 1 ) ) = $
  bytscl( image2, min = imin, max = imax, top = !d.table_size - 3 )

beyond_scl=where((bottom_vals eq 0B),byndcnt)
if byndcnt gt 0 then newimage(beyond_scl)=255B

image2 = 0




;- extract portion of image which fits within map boundaries

x = !x.window * ns
y = !y.window * nl
newimage = temporary( newimage( x(0):x(1), y(0):y(1) ) )

;- compute image offset and size (device coordinates)

p = convert_coord( [ x(0), x(1) ] / float( ns ), [ y(0), y(1) ] / float( nl ), $
  /normal, /to_device )
xoffset = p(0,0)
yoffset = p(1,0)
xsize = p(0,1) - p(0,0)
ysize = p(1,1) - p(1,0)

;- fill holes in resampled image

nxr = 4
nyr = 4
if keyword_set( lowres ) then begin
  nxr = 7
  nyr = 7
  if ( !d.flags and 1 ) then begin
    nxr = 5
    nyr = 5
  endif
endif
fill = dilate( newimage, replicate( 1, nxr, nyr ), /gray )
loc = where( ( fill ge 1b ) and ( newimage eq 0 ), count )
if count ge 1 then newimage( loc ) = fill( loc )
fill = 0

;- fill remaining undefined areas of image with the missing value
missing = 0B
loc = where( newimage eq 0B, count )
if ( count ge 1 ) and ( missing gt 0B) then newimage( loc ) = missing

colorimage=newimage

xparameter=intarr(4)
xparameter(0)= xoffset
xparameter(1)= yoffset
xparameter(2)= xsize
xparameter(3) =ysize

end
