pro GetOptimumScale,filenames,datatype,scale,center,finallimits,starttile,endtile,tilesize,InputYsize
fileindex=0
; IDL routine
;
; optimumscale.pro v 1.0
;
;    This code makes a stab at estimating lat/long boundaries for
;    one or several MODIS level 1-b granules and then estimates
;    a scale value for possible use with the IDL orthographic map
;    projection.
; 
; v 0.5 notes:  scale is a guess. not very well tested. the result might be
;               non-optimum, despite the routine name. :)
;
; Keywords:
;   none
;
; Input:
;    filenames   string array  all filenames to be checked
;    numberoffiles integer     the number of files in filenames
;
; Output:
;    scale         real         estimated scale for orthographic projection
;    center        real array   lat long center of all files
;    finallimits   real array   lat long upper and lower bounds for all files
;
; Required routines:
;    none
;
; Developer
;  v .5         Mark Gray mag@climate.gsfc.nasa.gov
;               SM&A - SSG
;               MODIS - Atmosphere Group
;

minlat=0
minlong=0
sizeinfo=size(filenames)

numberoffiles=sizeinfo[1]

case 1 of
  total(abs(finallimits)) eq 0 : begin


     leftlimits=fltarr(numberoffiles,4)
     rightlimits=fltarr(numberoffiles,4)

     centerpoint=fltarr(numberoffiles,2)
     for fileloop=0,numberoffiles-1 do  begin

        GetLatLongArrays,datatype[fileloop],0,0,filenames[fileloop],latitude,longitude
        badvalues=where(latitude lt -300,badcount)
        for i=0 , 1 do begin

          if i eq 0 then array=latitude
          if i eq 1 then array=longitude

          badvalues=where(array lt -300, badcount)

          if badcount gt 0 then  begin
            arraysizetemp=size(array) 
            array[badvalues]= 0.
            mean=total(array)/(arraysizetemp[1]*arraysizetemp[2])
            array[badvalues]=mean 
          endif

          if i eq 0 then latitude=array
          if i eq 1 then longitude=array

        endfor

        dummy=size(latitude)
        longitude=longitude+180.
        latitude=latitude+90.

        linemax=dummy(2)-1
        pixelmax=dummy(1)-1
    
        leftlimits[fileloop,0:3]=[ latitude[0,0], $
                                   latitude[0,linemax], $
                                   longitude[0,0], $
                                   longitude[0,linemax] ]

        rightlimits[fileloop,0:3]=[latitude[pixelmax,0], $
                                   latitude[pixelmax,linemax], $
                                   longitude[pixelmax,0], $
                                   longitude[pixelmax,linemax]]

        centerpoint[fileloop,0]=latitude[pixelmax/2,linemax/2]
        centerpoint[fileloop,1]=longitude[pixelmax/2,linemax/2]

     endfor
     starttile=intarr(numberoffiles)
     endtile=intarr(numberoffiles)

     StartTile[*]=0
     EndTile[0:numberoffiles-1]=fix(InputYSize[0:numberoffiles-1]/tilesize)-1

     finallimits=fltarr(4)

    ;overall latitude
     finallimits[0]=min([leftlimits[*,0:1],rightlimits[*,0:1]])
     finallimits[2]=max([leftlimits[*,0:1],rightlimits[*,0:1]])

    ;overall longitude
     finallimits[1]=min(leftlimits[*,2:3])
     finallimits[3]=max(rightlimits[*,2:3])


     center=fltarr(2)
     center[0]=total(centerpoint[*,0])/float(fileloop)
     center[1]=total(centerpoint[*,1])/float(fileloop)

     center[1]=center[1]-180.
     finallimits[1]=finallimits[1]-180.
     finallimits[3]=finallimits[3]-180.

     center[0]=center[0]-90.
     finallimits[0]=finallimits[0]-90.
     finallimits[2]=finallimits[2]-90.
  end
  total(abs(finallimits)) gt 0 : begin

; get starttiles, endtiles
    starttile=intarr(numberoffiles)
    endtile=intarr(numberoffiles)

    StartTile[*]=0
    EndTile[0:numberoffiles-1]=fix(InputYSize[0:numberoffiles-1]/tilesize)-1

;    for fileloop=0,numberoffiles-1 do  begin
;   
;        GetLatLongArrays,datatype[fileloop],0,0,filenames[fileloop],latitude,longitude
;    endfor
    center=fltarr(2)
    center[0]=(finallimits[0]+finallimits[2])/2.
    center[1]=(finallimits[1]+finallimits[3])/2.


  end
endcase 
; OK, it's estimated guess time
; I assume that 1 degree is approx 150km to be generous

xsize=abs(finallimits[0]-finallimits[2])*10.e3
ysize=abs(finallimits[1]-finallimits[3])*10.e3
;print,finallimits
;for i=0,3 do if(finallimits[i] gt 180.) then finallimits[i]=finallimits[i]-360.
;print,finallimits

print,finallimits

print,center

end
