; IDL view_l1b

; This code produces imagery from either 3 channels or a
; single selected channel for MODIS L1B imagery.

; output images are either tiff (8 bits per channel) jpeg or ps
; for a user selected map projection with map and lat/long
; grid notation either generated, or not at the user's disctretion

; the basic logic is
;  - get info on the granule of interest
;  - get lat/lon fields and regrid to data resolution
;  - setup map projection based on lat/long limits 
;    (either auto, or lat long supplied by the user)
;    and setup image output where required (ie:ps)
;
;  - main loop, remap the data, by tile
;     - read 22 lines of data and related lat/long info
;       (22 = 20 lines and 1 at each end that over laps prior/following tiles)
;     - for each sub-block regrid the block Nx the original size
;     - regrid the lat longs as well
;     - remap this data into image field
;
;  - add notation
;  - output to imagefile
;
; Various Settings ---

;   - settings here are variables that you might want to alter to produce
;     particular things (ie: larger output images, etc). If you don't see what
;     you need here then you'll have to search through the code.

;  the x and y size (pixels) of the final generated image. Note that these dimensions
;  are not really related to the input data (level 1-b) dimensions.  If you have
;  some serious memory problems you might try reducing these numbers
size='medium'
 
case 1 of
  size eq 'small': begin
      ;small size
      OutputImageXsize=900
      OutputImageYsize=750
      mapsize=100
      rescale=1
  end
    size eq 'medium': begin
      ;small size
      OutputImageXsize=1300
      OutputImageYsize=1050
      mapsize=150
      rescale=2
  end
  size eq 'normal': begin
      ;Normal size
      OutputImageXsize=1800
      OutputImageYsize=1500
      mapsize=200
      rescale=4
  end
  size eq 'large' : begin
      ;Big size
      OutputImageXsize=3600
      OutputImageYsize=3000
      mapsize=200
      rescale=5
  end
  size eq 'huge': begin
      ;Huge image
      oUtputImageXsize=5400
      OutputImageYsize=4500
      mapsize=300
      rescale=8
  end
endcase
;  enter something here for specific title other 
;  than the one automatically generated
TitleText=''

;tilesize is the number of lines of pixels for each tile
;tilesize=40
tilesize=fix((2708000d/(1354d*rescale^2)))

;  End of Settings ---


;select input l1b file
ChooseInputFile,l1bname,dir
; setup file looping
dummy=size(l1bname)
NumberofFiles=dummy[1]
fileindex=0

datatype=strarr(NumberofFiles)

print,NumberofFiles,'->files'

;check what kind of data we have here
if NumberofFiles lt 5 then begin
for fileindex=0,NumberofFiles-1 do begin
  GetDataType,l1bname[fileindex],dir,singledatatype
  datatype[fileindex]=singledatatype
endfor
endif else begin
 ; assume all files are the same 
  GetDataType,l1bname[0],dir,singledatatype
  datatype[0:NumberofFiles-1]=singledatatype
endelse
FullPathName=dir+l1bname

;select output options
ChooseDisplayOptions,datatype[0],format,notation,channels,projection,sds_name,outfilename

GenerateOutputFilename,l1bname,outfilename

;get some info from the l1b file

InputXsize=intarr(NumberofFiles)
InputYsize=intarr(NumberofFiles)
TotalDayScans=intarr(NumberofFiles)
TotalChannels=intarr(NumberofFiles)
newdatatype=strarr(NumberofFiles)
newfilelist=strarr(NumberofFiles)
newindex=0

print,'Sorting daytime scans from nighttime scans'
for fileindex=0,NumberofFiles-1 do begin
   GetArraySizeInfo,FullPathName[fileindex],$
              datatype[fileindex],$
              sds_name,$
              SingleInputXsize,$
              SingleInputYsize,$
              SingleTotalDayScans,$
              SingleTotalChannels
   InputXsize[fileindex]=SingleInputXsize
   InputYsize[fileindex]=SingleInputYsize
   TotalDayScans[fileindex]=SingleTotalDayScans
   TotalChannels[fileindex]=SingleTotalChannels

   if SingleTotalDayScans gt 0 then begin
      InputXsize[newindex]=SingleInputXsize
      InputYsize[newindex]=SingleInputYsize
      TotalDayScans[newindex]=SingleTotalDayScans
      TotalChannels[newindex]=SingleTotalChannels
      newfilelist[newindex]=FullPathName[fileindex] 
      newdatatype[newindex]=datatype[fileindex]
      newindex=newindex+1
   endif
endfor

InputXsize=InputXsize[0:newindex-1]
InputYsize=InputYsize[0:newindex-1]
TotalDayScans=TotalDayScans[0:newindex-1]
TotalChannels=TotalChannels[0:newindex-1]
newfilelist=newfilelist[0:newindex-1]
datatype=newdatatype[0:newindex-1]
FullPathName=newfilelist[0:newindex-1]
NumberofFiles=newindex

;get optimum lat long limits
;set the limits vector to the lat long limits you need, 
;otherwise limits=0 enforces the 
;default (the limits are the limits of the granule)
;limits=[36,-80,40,-72]
;limits=[-21.,21.,-17.,25.]
;limits=[15.,-107.,23.,-101.] ;manz, mx
;limits=[21.,68.,25.,72.]
;limits=[-19.,10.,-23.,15.]
;limits=[28.,-130.,39.,-122.]
limits=0

;set the start and end tile to process something other than the entire
;granule.  Dynamical setting of these numbers is in the works.

if projection ne 3 and projection ne 4 and projection ne 5 then begin
   GetOptimumScale,FullPathName,$
                datatype,$
                scale,$
                center,$
                limits,$
                starttile,$
                endtile,$
                tilesize,$
                InputYsize
   if (mapsize gt 0 ) then minimap=GetMiniMap(center,mapsize)
endif else begin
   limits=0.
   center=[0.,0.]
   rescale=0
   InputXsize=fix(InputXsize/abs(rescale))
   InputYsize=fix(InputYsize/abs(rescale))
endelse

;HACK here
tempdata=datatype
datatype=0
datatype=tempdata[0]

title=l1bname[0]
;  Setup output image device, as far as we are able at this point
SetupOutputImage,datatype,$
                 projection,$
                 format,$
                 OutputImageXsize,$
                 OutputImageYsize,$
                 limits,$
                 center,$
                 scale,$
                 title,$
                 outfilename

getoverallmaxmin,datatype,maxmin,fullpathname,channels,numberoffiles,InputXSize,InputYSize,sds_name
firstfile =0
lastfile=NumberofFiles-1
print,maxmin
for  fileindex = firstfile, lastfile do begin
   print,'Rendering file',fileindex+1,' of ',lastfile+1
   if rescale gt 0 then begin
   original_tilesize=tilesize
   GenerateRemappedImage,FullPathName[fileindex],$
                      datatype,$
                      sds_name,$
                      maxmin,$
                      InputXsize[fileindex],$
                      InputYsize[fileindex],$
                      Starttile[fileindex],$
                      Endtile[fileindex],$
                      tilesize,$
                      latitude,$
                      longitude,$
                      channels,$
                      image,$
                      xparameter,rescale,fileindex
  tilesize=original_tilesize
  endif else begin
    GenerateReScaledImage,FullPathName[fileindex],$
                      datatype,$
                      maxmin,$
                      InputXsize[fileindex],$
                      InputYsize[fileindex],$
                      latitude,$
                      longitude,$
                      channels,$
                      rescale,$
                      image,$
                      xparameter,fileindex,firstfile
   endelse
endfor

curvefile='prettymodis.amp'
if curvefile ne '' then ApplyColorCurve,curvefile,image

;AddNotationToImage,Image
if projection ne 3 and projection ne 4 and projection ne 5 then begin
   OutputImageFile,image,format,xparameter,minimap,mapsize,notation,outfilename
endif else begin
   minimap=0
   mapsize=0
   OutputImageFile,image,format,xparameter,minimap,mapsize,notation,outfilename
endelse

end
