pro addproduct,mod06filename,latlongfile,colorimage,sds_name,xparameter, $
               productname,sds_limits,multidim_choice,diff_flag,         $
               delta_zero,water_flag,log_scale,fail,quick = quick

;*************************************************************************
; Modification history:
;  11/08/2001
;    Initial Release.
;
; Credits:
;  Written by Eric G. Moody and Mark Gray.
;  eric.moody@gsfc.nasa.gov
;  gray@climate.gsfc.nasa.gov
;  Climate and Radiation Branch
;  NASA Goddard Space Flight Center
;  Greenbelt, Maryland, U.S.A.
;
; License:
; This software is provided "as-is", without any express or
; implied warranty. In no event will the authors be held liable
; for any damages arising from the use of this software.
;
; Permission is granted to anyone to use this software and to alter
; it freely, subject to the following restrictions:
;
; 1. The origin of this software must not be misrepresented; you must
;    not claim you wrote the original software.
;
; 2. Altered source versions must be plainly marked as such, and must
;    not be misrepresented as being the original software.
;
; 3. This notice may not be removed or altered from any source distribution.
;*************************************************************************


;
fail=0


get_modis_data,mod06filename,latlongfile,sds_name,latitude,longitude, $
               sds_data,fillvalue,fail1,datarange,multidim_choice
if fail1 ne 1 then begin

;Ensure they are floats:
fillvalue = float(fillvalue)
sds_data=float(sds_data)

;If this is a difference field, check to see if difference field is to be plotted,
;  or if we should add off the 2.1:
if (sds_name eq 'Effective_Radius_Difference') then begin
  ;If we want a difference, add the Re, 2.1 micron result:
  if (diff_flag eq 0) then begin
    ;We are plotting the effective radius, so read in the 2.1, and 
    ; add it to the difference.
    get_modis_data,mod06filename,latlongfile,'Effective_Particle_Radius', $
                   latitude2,longitude2, EPR_data,fillvalue2,fail2,datarange,0

    EPR_data = float(EPR_data)
    fillvalue2 = float(fillvalue2)
 
    ;Reset the fill values to the fill value:
    index = where((sds_data eq fillvalue),fill_cnt)
    sds_data[*,*] = sds_data[*,*] + EPR_data[*,*]
    if fill_cnt gt 0 then sds_data[index] = fillvalue

  endif else begin
    ;We are plotting the differences, and would like any value +- delta_zero 
    ; to be gray.

    ;Read in the color table, to adjust:
    tvlct,r,g,b,/get

    ;First work on the Ice color scale (ranges between 0-126).
    ;Define the upper and lower limits to set to white 
    top_lim = delta_zero(1)
    bot_lim = delta_zero(0)
    ;Figure out the index of the upper and lower points to
    ; be shaded white:
    tot_cb_levels = 127.
    delta_cb = (sds_limits(0,1)-sds_limits(0,0)) / tot_cb_levels
    tot_gray_lvls = fix( abs(top_lim-bot_lim) / delta_cb )

    bot_lvl = fix( abs(bot_lim-sds_limits(0,0))  /delta_cb )
    top_lvl = bot_lvl + tot_gray_lvls 
 
    ;Set those levels to a light gray:
    r(bot_lvl:top_lvl) = 150B
    g(bot_lvl:top_lvl) = 150B
    b(bot_lvl:top_lvl) = 150B


    ;Next work on the Water color scale (ranges between 127-253).
    ;Define the upper and lower limits to set to white
    top_lim = delta_zero(1)
    bot_lim = delta_zero(0)
    ;Figure out the index of the upper and lower points to
    ; be shaded white:
    tot_cb_levels = 127.
    delta_cb = (sds_limits(0,1)-sds_limits(0,0)) / tot_cb_levels
    tot_gray_lvls = fix( abs(top_lim-bot_lim) / delta_cb )

    bot_lvl = fix( abs(bot_lim-sds_limits(0,0))  /delta_cb ) + 127
    top_lvl = bot_lvl + tot_gray_lvls
 
    ;Set those levels to a light gray:
    r(bot_lvl:top_lvl) = 75B
    g(bot_lvl:top_lvl) = 75B
    b(bot_lvl:top_lvl) = 75B


    ;Set the color table:
    tvlct,r,g,b

  endelse
;End the if effective radius if statement:
endif


;Ensure that the data is float:
sds_data  = float(sds_data)
fillvalue = float(fillvalue)


;Read in the L2 QA and extract the cloud phase:
Cloud_Phase = l2qa_bitextracter(mod06filename)


;Obtain the size of the data arrays:
dimsizes = size(sds_data)
data_xsize = dimsizes(1)
data_ysize = dimsizes(2)


;Break the combined data into phases, store in an array,
;  where the indices mean:
;  Phase_data[0,*,*] = Ice
;  Phase_data[1,*,*] = Water, Undetermined, Water+Undetermined
Phase_data    = fltarr(2,data_xsize,data_ysize)

;Ice:
dummy_data = sds_data
indices = where((Cloud_Phase ne 3),ind_cnt)
if (ind_cnt gt 0) then dummy_data(indices) = fillvalue
Phase_data[0,*,*] = dummy_data[*,*]

;Create the water/undetermined/water+undetermined array
case water_flag of
  0 :  begin
        ;Water:
        dummy_data = sds_data
        indices = where((Cloud_Phase ne 2),ind_cnt)
        if (ind_cnt gt 0) then dummy_data(indices) = fillvalue
        Phase_data[1,*,*] = dummy_data[*,*]
       end
  1 :  begin
        ;Undetermined:
        dummy_data = sds_data
        indices = where((Cloud_Phase ne 4),ind_cnt)
        if (ind_cnt gt 0) then dummy_data(indices) = fillvalue
        Phase_data[1,*,*] = dummy_data[*,*]
       end
  2 :  begin
        ;Water + Undetermined:
        dummy_data = sds_data
        dummy_data[*,*] = fillvalue
        indices = where( (Cloud_Phase eq 2) or (Cloud_Phase eq 4), ind_cnt)
        if (ind_cnt gt 0) then dummy_data(indices) = sds_data(indices)
        Phase_data[1,*,*] = dummy_data[*,*]
       end
endcase




datarange=sds_limits
if keyword_set(quick) then colorproductmap,Phase_data,$
                                         latitude,$
                                         longitude,$
                                         colorimage,$
                                         fillvalue,$
                                         datarange,$
                                         log_scale,$
                                         xparameter,$
                                         /dilateno
if not keyword_set(quick) then colorproductmap,Phase_data,$
                                         latitude,$
                                         longitude,$
                                         colorimage,$
                                         fillvalue,$
                                         datarange,$
                                         log_scale,$
                                         xparameter,$
                                         /validrange

sds_data=0
latitude=0
longitude=0

endif else begin
  print,'no data here'
  fail=1
endelse
end
