pro plot_phase,filenames,sds_name,outputname,sds_limits,  $
                       latlonglimits,titlestring,multidim_choice, $
                       difference_flag,Num_CB_Levels,delta_zero,  $
                       water_flag,log_scale,                      $
                       cylindrical=cylindrical,ps=ps,jpeg=jpeg,   $
                       tiff=tiff,notation=notation,local=local

;*************************************************************************
; Modification history:
;  11/08/2001
;    Initial Release.
;
; Credits:
;  Written by Eric G. Moody and Mark Gray.
;  eric.moody@gsfc.nasa.gov
;  gray@climate.gsfc.nasa.gov
;  Climate and Radiation Branch
;  NASA Goddard Space Flight Center
;  Greenbelt, Maryland, U.S.A.
;
; License:
; This software is provided "as-is", without any express or
; implied warranty. In no event will the authors be held liable
; for any damages arising from the use of this software.
;
; Permission is granted to anyone to use this software and to alter
; it freely, subject to the following restrictions:
;
; 1. The origin of this software must not be misrepresented; you must
;    not claim you wrote the original software.
;
; 2. Altered source versions must be plainly marked as such, and must
;    not be misrepresented as being the original software.
;
; 3. This notice may not be removed or altered from any source distribution.
;*************************************************************************



; take the filename and extact substrings which allow us to generalise
; the treatment of the image (for titles, and so on)

modisnameparser,filenames[0],productname,year,textmonth,day,time,subname,julday


; bug fix get lat longs from l1b file for local processing since the 
; locally processed PGE06 code results may be generated with incorrect
; lat long arrays

if not keyword_set(local) then begin
  latlongfile = filenames
endif else begin
  textyear = strcompress( string(year),/remove_all )
  textjulday = strcompress( string(julday),/remove_all )
  filespec = '/ingest/MOD021KM/' + textyear + '/' + textjulday + '/' + '*' + textyear + textjulday + '.' + time + '*'
  latlongfile = findfile( filespec,count=countvar )
endelse


; build titletext used for image notation

datestring=strcompress( textmonth + ' ' + string(day) + ', ' + string(year) + ', ' + time + ' UTC' )
;titlestring = datestring + sds_name +'  (' + subname + ')'
;titlestring = datestring + ', ' + sds_name
if not keyword_set(notation) then titlestring = ''

numberoffiles = size(filenames)
numberoffiles = numberoffiles[1]

if not keyword_set(world) then begin
  if n_elements(latlonglimits) eq 4 then begin
     center=fltarr(2)
     center[0]=(latlonglimits[0]+latlonglimits[2])/2.
     center[1]=(latlonglimits[1]+latlonglimits[3])/2.
  endif else begin
     optimumscale,latlongfile,numberoffiles,scalesetting,center,latlonglimits
  endelse

  print,'Lat/long limits are :'
  print,latlonglimits[0],latlonglimits[2],'   degrees latitude'
  print,latlonglimits[1],latlonglimits[3],'   degrees longitude'

  mapsize = 150
;  worldmap = make_minimap( center[0],center[1],mapsize )
endif



if  keyword_set(world) then begin
    if keyword_set(ps)   then setup_display,filenames,$
                                            titlestring,$
                                            outputname,$
                                            /world,$
                                            /ps
    if keyword_set(jpeg) then setup_display,filenames,$
                                            titlestring,$
                                            outputname,$
                                            /world,$
                                            /jpeg
endif else begin
    if keyword_set(ps) then setup_display,filenames,$
                                          titlestring,$
                                          outputname,$
                                          scalesettings,$
                                          latlonglimits,$
                                          center,$
                                          /ps
    if keyword_set(jpeg) or keyword_set(tiff) and $
       not keyword_set(cylindrical) then setup_display,filenames,$
                                                           titlestring,$
                                                           outputname,$
                                                           scalesettings,$
                                                           latlonglimits,$
                                                           center,$
                                                           /jpeg
    if keyword_set(jpeg) or keyword_set(tiff) and $
       keyword_set(cylindrical) then setup_display,filenames,$
                                                   titlestring,$
                                                   outputname,$
                                                   scalesettings,$
                                                   latlonglimits,$
                                                   center,$
                                                   /jpeg,$
                                                   /cylindrical
endelse

; Having setup the display and some basic notational strings we can get busy with acquiring
; the actual data

imageflag=0
faillist=intarr(numberoffiles)

for fileloop=0,numberoffiles-1 do begin
 print,filenames[fileloop],' is being acquired. Please stand by'
 modisnameparser,filenames[fileloop],$
                 productname,$
                 year,$
                 textmonth,$
                 day,$
                 time,$
                 subname,$
                 julday
 if keyword_set(world) then  addproduct,filenames[fileloop],$
                                        addimage,$
                                        sds_name,$
                                        xparameter,$
                                        productname,$
                                        sds_limits,$
                                        multidim_choice,$
                                        difference_flag,$
                                        delta_zero,$
                                        water_flag,$
                                        log_scale,$
                                        fail,$
                                        /quick
 if not keyword_set(world) then addproduct,filenames[fileloop],$
                                           latlongfile[0],$
                                           addimage,$
                                           sds_name,$
                                           xparameter,$
                                           productname,$
                                           sds_limits,$
                                           multidim_choice,$
                                           difference_flag,$
                                           delta_zero,$
                                           water_flag,$
                                           log_scale,$
                                           fail
; if fileloop gt 0 then stop
 if fail eq 0 then imageflag=imageflag+1

 if fail  eq 1 then faillist[fileloop]=1

 if  imageflag eq 1 then finalimage=addimage

 if  imageflag gt 1 and fail eq 0 then begin
   unsetpixels = where( finalimage eq 0 ,unsetcount )
   goodaddpixels = where( addimage gt 0,goodaddcount )
   if goodaddcount gt 0 then finalimage(goodaddpixels) = addimage(goodaddpixels)
   addimage = 0
 endif
endfor

totalfail = 0
if total(faillist) lt numberoffiles then begin
  totalfail = 0
endif else begin
  totalfail = 1
endelse


if totalfail eq 0 then begin
  if keyword_set(notation) then begin

;    if not keyword_set(world) then finalimage[0:mapsize-1,0:mapsize-1]=$
;                                      worldmap[0:mapsize-1,0:mapsize-1]

    if keyword_set(ps) then output_productmap,finalimage,$
                                              sds_limits,$
                                              xparameter,$
                                              outputname,$
                                           Num_CB_Levels,$
                                               log_scale,$ 
                                              /psdisplay,$
                                              /notation
    if keyword_set(jpeg) then  output_productmap,finalimage,$
                                                 sds_limits,$
                                                 xparameter,$
                                                 outputname,$
                                              Num_CB_Levels,$
                                                  log_scale,$
                                                      /jpeg,$
                                                    /notation
    if keyword_set(tiff) then  output_productmap,finalimage,$
                                                 sds_limits,$
                                                 xparameter,$
                                                 outputname,$
                                              Num_CB_Levels,$
                                                  log_scale,$
                                                 /tiff,$
                                                 /notation
  endif else begin
    if keyword_set(ps) then output_productmap,finalimage,$
                                              sds_limits,$
                                              xparameter,$
                                              outputname,$
                                           Num_CB_Levels,$
                                               log_scale,$
                                              /psdisplay
    if keyword_set(jpeg) then  output_productmap,finalimage,$
                                                 sds_limits,$
                                                 xparameter,$
                                                 outputname,$
                                              Num_CB_Levels,$
                                                  log_scale,$
                                                 /jpeg
    if keyword_set(tiff) then  output_productmap,finalimage,$
                                                 sds_limits,$
                                                 xparameter,$
                                                 outputname,$
                                              Num_CB_Levels,$
                                                  log_scale,$
                                                 /tiff
  endelse
endif

end
